@@ -1,4 +1,10 @@
 package Tapper::CLI::API::Command::download;
+BEGIN {
+  $Tapper::CLI::API::Command::download::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::CLI::API::Command::download::VERSION = '4.0.1';
+}
 
 use 5.010;
 
@@ -58,7 +64,7 @@ sub validate_args
         die $self->usage->text;
 }
 
-sub execute 
+sub execute
 {
         my ($self, $opt, $args) = @_;
 
@@ -107,3 +113,27 @@ sub download
 # perl -Ilib bin/tapper-api download --reportid=552 --file ~/xyz --nth=1 --saveas=/tmp/myxyz
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::CLI::API::Command::download
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
