@@ -1,4 +1,10 @@
 package Tapper::CLI::DbDeploy::Command::init;
+BEGIN {
+  $Tapper::CLI::DbDeploy::Command::init::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::CLI::DbDeploy::Command::init::VERSION = '4.0.1';
+}
 
 use 5.010;
 
@@ -125,3 +131,27 @@ sub run
 # perl -Ilib bin/tapper-db-deploy init --db=ReportsDB
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::CLI::DbDeploy::Command::init
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
