@@ -1,4 +1,10 @@
 package Tapper::CLI::Testrun::Command::listhost;
+BEGIN {
+  $Tapper::CLI::Testrun::Command::listhost::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::CLI::Testrun::Command::listhost::VERSION = '4.0.1';
+}
 
 use 5.010;
 
@@ -15,11 +21,12 @@ sub abstract {
 
 my $options = { "verbose"  => { text => "show all available information; without only show names", short => 'v' },
                 "queue"    => { text => "list hosts bound to this queue", type=> 'manystring'},
-                "active"   => { text => "list active hosts"},
+                "all"      => { text => "list all hosts, even deleted ones"},
+                "active"   => { text => "list only active hosts"},
                 "free"     => { text => "list free hosts" },
                 "name"     => { text => "find host by name, implies verbose", type => 'string'},
               };
-                
+
 
 
 sub opt_spec {
@@ -59,7 +66,7 @@ sub _extract_bare_option_names {
 sub validate_args {
         my ($self, $opt, $args) = @_;
 
-        
+
         my $msg = "Unknown option";
         $msg   .= ($args and $#{$args} >=1) ? 's' : '';
         $msg   .= ": ";
@@ -88,9 +95,13 @@ sub execute {
         my ($self, $opt, $args) = @_;
         my %options= (order_by => 'name');
         my %search;
-        $search{active} = 1 if $opt->{active};
+        $search{active}     = 1 if $opt->{active};
+        $search{is_deleted} = {-in => [ 0, undef ] } unless $opt->{all};
         $search{free}   = 1 if $opt->{free};
-        $search{name}   = $opt->{name}  if $opt->{name};
+
+        # ignore all options if host is requested by name
+        %search = (name   => $opt->{name}) if $opt->{name};
+
         if ($opt->{queue}) {
                 my @queue_ids       = map {$_->id} model('TestrunDB')->resultset('Queue')->search({name => {-in => [ @{$opt->{queue}} ]}});
                 $search{queue_id}   = { -in => [ @queue_ids ]};
@@ -127,7 +138,7 @@ sub print_hosts_verbose
                 }
         }
         my ($name_length, $comment_length, $queue_length) = ($max{name}, $max{comment}, $max{queue});
-        
+
         # use printf to get the wanted field width
         printf ("%5s | %${name_length}s | %11s | %10s | %${comment_length}s | Queues\n",'ID','Name','Active', 'Testrun ID', 'Comment');
         say "="x(5+$name_length+11+length('Testrun ID')+$comment_length+length('Queues')+5*length(' | '));
@@ -140,16 +151,16 @@ sub print_hosts_verbose
                         my $job_rs = model('TestrunDB')->resultset('TestrunScheduling')->search({host_id => $host->id, status => 'running'});
                         $testrun_id = $job_rs->first->testrun_id if $job_rs->count;
                 }
-                my $output = sprintf("%5d | %${name_length}s | %11s | %10s | %${comment_length}s | ", 
-                                     $host->id, 
-                                     $host->name, 
-                                     $host->active ? 'active' : 'deactivated', 
+                my $output = sprintf("%5d | %${name_length}s | %11s | %10s | %${comment_length}s | ",
+                                     $host->id,
+                                     $host->name,
+                                     $host->is_deleted ? 'deleted' : ( $host->active ? 'active' : 'deactivated' ),
                                      $host->free   ? 'free'   : "$testrun_id",
                                      $host->comment,
                                     );
                 if ($host->queuehosts->count) {
                         $output .= join ", ", map {$_->queue->name} $host->queuehosts->all;
-                } 
+                }
                 say $output;
         }
 }
@@ -158,3 +169,27 @@ sub print_hosts_verbose
 1;
 
 # perl -Ilib bin/tapper-testrun list --id 16
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::CLI::Testrun::Command::listhost
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
