@@ -1,4 +1,10 @@
 package Tapper::CLI::Testrun::Command::newhost;
+BEGIN {
+  $Tapper::CLI::Testrun::Command::newhost::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::CLI::Testrun::Command::newhost::VERSION = '4.0.1';
+}
 
 use 5.010;
 
@@ -79,7 +85,7 @@ sub new_host
                     active => $opt->{active},
                     free   => 1,
                    };
-        
+
         my $newhost = model('TestrunDB')->resultset('Host')->new($host);
         $newhost->insert();
         die "Can't create new host" if not $newhost;
@@ -102,7 +108,7 @@ sub new_host
         say $newhost->id;
 }
 
-sub execute 
+sub execute
 {
         my ($self, $opt, $args) = @_;
 
@@ -113,3 +119,27 @@ sub execute
 # perl -Ilib bin/tapper-testrun newqueue --name="xen-3.2" --priority=200
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::CLI::Testrun::Command::newhost
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
