@@ -1,4 +1,10 @@
 package Tapper::CLI::Testrun::Command::updatehost;
+BEGIN {
+  $Tapper::CLI::Testrun::Command::updatehost::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::CLI::Testrun::Command::updatehost::VERSION = '4.0.1';
+}
 
 use 5.010;
 
@@ -8,6 +14,8 @@ use warnings;
 use parent 'App::Cmd::Command';
 
 use Tapper::Model 'model';
+use Tapper::Config;
+
 
 sub abstract {
         'Update an existing host'
@@ -18,7 +26,7 @@ my $options =  {
                 "verbose"          => { text => "some more informational output", short=> 'v' },
                 "id"               => { text => "INT; change host with this id; required", type => 'optstring'},
                 "name"             => { text => "TEXT; update name",    type => 'string' },
-                "active"           => { text => "set active flag to this value, prepend with not to unset", type => 'withno' },
+                "active"           => { text => "set active flag to this value, prepend with no to unset", type => 'withno' },
                 "comment"          => { text => "Set a new comment for the host", type => 'string'},
                 "addqueue"         => { text => "TEXT; Bind host to named queue without deleting other bindings (queue has to exists already)", type => 'manystring'},
                 "delqueue"         => { text => "TEXT; delete queue from this host's bindings, empty string means 'all bindings'", type => 'optmanystring'},
@@ -55,7 +63,19 @@ sub validate_args
                 die $self->usage->text;
         }
 
-        $opt->{active} = 1 if @$args and (grep {$_ eq '--active'} @$args);   # allow --active, even though it's not official
+        if (@$args and (grep {$_ eq '--active'} @$args)) { # allow --active, even though it's not official
+                @$args = grep {$_ ne '--active'} @$args;
+                $opt->{active} = 1;
+        }
+
+        # Prevent unknown options
+        my $msg = "Unknown option";
+        $msg   .= ($args and $#{$args} >=1) ? 's' : '';
+        $msg   .= ": ";
+        if (($args and @$args)) {
+                say STDERR $msg, join(', ',@$args);
+                die $self->usage->text;
+        }
 
         if ($opt->{name} and not $opt->{id}) {
                 my $host = model('TestrunDB')->resultset('Host')->search({name => $opt->{name}})->first;
@@ -130,7 +150,19 @@ sub del_queues
         }
 }
 
-sub execute 
+
+sub update_grub
+{
+        my ($self, $hostname) = @_;
+        my $message = model('TestrunDB')->resultset('Message')->new({type => 'action',
+                                                                     message => {action => 'updategrub',
+                                                                                 host   => $hostname,
+                                                                                }});
+        $message->insert;
+        return 0;
+}
+
+sub execute
 {
         my ($self, $opt, $args) = @_;
         my $host;
@@ -138,25 +170,62 @@ sub execute
         $host = model('TestrunDB')->resultset('Host')->find($opt->{id});
         die "No such host: $opt->{id}" if not  $host;
 
-        $host->active($opt->{active}) if defined($opt->{active});
+        if (defined($opt->{active})) {
+                $host->active($opt->{active});
+                $self->update_grub($host->name)
+                  if $opt->{active} == 0;
+        }
+
         $host->name($opt->{name}) if $opt->{name};
         $self->del_queues($host, $opt->{delqueue}) if $opt->{delqueue};
         $self->add_queues($host, $opt->{addqueue}) if $opt->{addqueue};
         $host->comment($opt->{comment}) if defined($opt->{comment});
         $host->update;
 
-        my $output = sprintf("%s | %s | %s | %s", 
-                             $host->id, 
-                             $host->name, 
-                             $host->active ? 'active' : 'deactivated', 
+        my $output = sprintf("%s | %s | %s | %s",
+                             $host->id,
+                             $host->name,
+                             $host->active ? 'active' : 'deactivated',
                              $host->free   ? 'free'   : 'in use');
         if ($host->queuehosts->count) {
                 foreach my $queuehost ($host->queuehosts->all) {
                         $output.= sprintf(" | %s",$queuehost->queue->name);
                 }
-        } 
+        }
         say $output;
 }
 
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::CLI::Testrun::Command::updatehost
+
+=head2 update_grub
+
+Install a default grub config for host so that it does no longer try to
+execute Tapper testruns.
+
+@return success - 0
+@return error   - die()
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
